==> hoteldruid-mod-sv_2.1.2-1.tar.gz: sv/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "L&auml;gg till ny bokning"; break;
case "Cliente titolare: cognome":  		$messaggio = "Huvudg&auml;st: efternamn"; break;
case "cognome":  				$messaggio = "efternamn"; break;
case "nome":  					$messaggio = "f&ouml;rnamn"; break;
case "Dal":  					$messaggio = "Fr&aring;n"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "Tipo di tariffa":  			$messaggio = "Pristyp"; break;
case "tariffa":  				$messaggio = "pris"; break;
case "sconto":  				$messaggio = "rabatt"; break;
case "caparra":  				$messaggio = "deposition"; break;
case "se diversa dalla normale":  		$messaggio = "om skiljd fr&aring;n det normala"; break;
case "nº di persone":  				$messaggio = "antal personer"; break;
case "Nº di piano":  				$messaggio = "V&aring;ningsnummer"; break;
case "e/o di casa":  				$messaggio = "och/eller husnummer"; break;
case "e/o di persone":  			$messaggio = "och/eller antal personer"; break;
case "costo aggiuntivo unico":  		$messaggio = "enkel extrakostnad"; break;
case "da moltiplicare per":  			$messaggio = "att multiplicera med"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "veckolig extrakostnad"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daglig extrakostnad"; break;
case "nº di settimane da applicare":  		$messaggio = "antal veckor att till&auml;mpa f&ouml;r"; break;
case "nº di giorni da applicare":  		$messaggio = "antal dagar att till&auml;mpa f&ouml;r"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "Inserisci la prenotazione":  		$messaggio = "Infoga bokningen"; break;
case "Torna al menù principale":  		$messaggio = "Tillbaka till huvudmenyn"; break;
case " o spezzarla":  				$messaggio = " eller dela den"; break;
case "Spezza la prenotazione in":  		$messaggio = "Dela bokningen i"; break;
case "parti":  					$messaggio = "delar"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "Det har inte varit m&ouml;jligt att delabokningen p&aring; grund av antalet personer"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "Det &auml;r inte m&ouml;jligt att infoga bokningen utan att"; break;
case "dividerla":  				$messaggio = "dela den"; break;
case "in":  					$messaggio = "i"; break;
case "Spezza la prenotazione in":  		$messaggio = "Dela bokningen i"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "Det var inte m&ouml;jligt att infoga bokningen f&ouml;r"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "eftersom databasen har &auml;ndrats under tiden"; break;
case "Prenotazione":  				$messaggio = "Bokning"; break;
case "settiman":  				$messaggio = "vecka"; break;
case "giorn":  					$messaggio = "dag"; break;
case "e":  					$messaggio = "ar"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "ar"; break;
case "a nome di":  				$messaggio = "f&ouml;r herr/fru"; break;
case "per":  					$messaggio = "f&ouml;r"; break;
case "persone":  				$messaggio = "personer"; break;
case "Costo unico":  				$messaggio = "Enkel kostnad"; break;
case "moltiplicato per":  			$messaggio = "multiplicerad med"; break;
case "Costo settimanale":  			$messaggio = "Veckolig kostnad"; break;
case "Costo giornaliero":  			$messaggio = "Daglig kostnad"; break;
case "settimane":  				$messaggio = "veckor"; break;
case "giorni":  				$messaggio = "dagar"; break;
case "TOTALE":  				$messaggio = "TOTALT"; break;
case "Caparra":  				$messaggio = "Deposition"; break;
case "resto da pagare":  			$messaggio = "&aring;terst&aring;end att betala"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "inserita":  				$messaggio = "infogad"; break;
case "Modifica la prenotazione":  		$messaggio = "&Auml;ndra bokning"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Sconto":  				$messaggio = "Rabatt"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Kundens efternamn beh&ouml;vs"; break;
case "confermata":  				$messaggio = "bekr&auml;ftad"; break;
case "Confermata":  				$messaggio = "Bekr&auml;ftad"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Antalet bokningar av den h&auml;r typen"; break;
case "Aggiungi altre tipologie":  		$messaggio = "L&auml;gg till andra typer"; break;
case "Tipologia":  				$messaggio = "Typ"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Inga nya bokningar har lagts till"; break;
case "Transazione scaduta":  			$messaggio = "Transaktion utg&aring;ngen"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "Det var inte m&ouml;jligt att l&auml;gga till en extrakostnad f&ouml;r bokningen f&ouml;r"; break;
case "Orario stimato di entrata":  		$messaggio = "Uppskattad incheckningstid"; break;
case "giorno":  				$messaggio = "dag"; break;
case "Metodo pagamento caparra":  		$messaggio = "Betalningsmetod f&ouml;r depositionen"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "Bokningarna som efterfr&aring;gas i meddelandet har redan lagts till"; break;
case "Attenzione":  				$messaggio = "Varning"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "det totala priset f&ouml;r infogade bokningar"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "det totala priset f&ouml;r infogade depositioner"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "&auml;r skiljt fr&aring;n det som ing&aring;r i bokningsf&ouml;rfr&aring;gansmeddelandet"; break;
case "Origine":  				$messaggio = "Ursprung"; break;
case "<b>Attenzione</b>: il prezzo totale":  		$messaggio = "<b>Varning</b>: totalt pris"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "&auml;r skiljt fr&aring;n avl&auml;gset pris"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "&Auml;ndra infogade bokningar som en grupp"; break;
case "prezzo totale":  				$messaggio = "total price"; break;
case "prezzo totale giornaliero":  		$messaggio = "daily total price"; break;
case "prezzo totale settimanale":  		$messaggio = "weekly total price"; break;
case "prezzo tarffa":  				$messaggio = "rate price"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "daily rate price"; break;
case "prezzo tariffa settimanale":  		$messaggio = "weekly rate price"; break;
case "% del totale":  				$messaggio = "% of total"; break;
case "% della tariffa":  			$messaggio = "% of rate"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "resto commissioni":  			$messaggio = "rest of commissions"; break;
case "% del prezzo totale":  			$messaggio = "% of total price"; break;
case "modificata":  				$messaggio = "modified"; break;
case "Errore":  				$messaggio = "Error"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "per l'entrata":  				$messaggio = "for checkin"; break;
case "per l'uscita":  				$messaggio = "for checkout"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_2.2.3-1.tar.gz: sv/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "L&auml;gg till ny bokning"; break;
case "Cliente titolare":  			$messaggio = "Huvudg&auml;st"; break;
case "cognome":  				$messaggio = "efternamn"; break;
case "nome":  					$messaggio = "f&ouml;rnamn"; break;
case "Dal":  					$messaggio = "Fr&aring;n"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "Tipo di tariffa":  			$messaggio = "Pristyp"; break;
case "tariffa":  				$messaggio = "pris"; break;
case "sconto":  				$messaggio = "rabatt"; break;
case "caparra":  				$messaggio = "deposition"; break;
case "se diversa dalla normale":  		$messaggio = "om skiljd fr&aring;n det normala"; break;
case "nº di persone":  				$messaggio = "antal personer"; break;
case "Nº di piano":  				$messaggio = "V&aring;ningsnummer"; break;
case "e/o di casa":  				$messaggio = "och/eller husnummer"; break;
case "e/o di persone":  			$messaggio = "och/eller antal personer"; break;
case "costo aggiuntivo unico":  		$messaggio = "enkel extrakostnad"; break;
case "da moltiplicare per":  			$messaggio = "att multiplicera med"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "veckolig extrakostnad"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daglig extrakostnad"; break;
case "nº di settimane da applicare":  		$messaggio = "antal veckor att till&auml;mpa f&ouml;r"; break;
case "nº di giorni da applicare":  		$messaggio = "antal dagar att till&auml;mpa f&ouml;r"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "Inserisci la prenotazione":  		$messaggio = "Infoga bokningen"; break;
case "Torna al menù principale":  		$messaggio = "Tillbaka till huvudmenyn"; break;
case " o spezzarla":  				$messaggio = " eller dela den"; break;
case "Spezza la prenotazione in":  		$messaggio = "Dela bokningen i"; break;
case "parti":  					$messaggio = "delar"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "Det har inte varit m&ouml;jligt att delabokningen p&aring; grund av antalet personer"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "Det &auml;r inte m&ouml;jligt att infoga bokningen utan att"; break;
case "dividerla":  				$messaggio = "dela den"; break;
case "in":  					$messaggio = "i"; break;
case "Spezza la prenotazione in":  		$messaggio = "Dela bokningen i"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "Det var inte m&ouml;jligt att infoga bokningen f&ouml;r"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "eftersom databasen har &auml;ndrats under tiden"; break;
case "Prenotazione":  				$messaggio = "Bokning"; break;
case "settiman":  				$messaggio = "vecka"; break;
case "giorn":  					$messaggio = "dag"; break;
case "e":  					$messaggio = "ar"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "ar"; break;
case "a nome di":  				$messaggio = "f&ouml;r herr/fru"; break;
case "per":  					$messaggio = "f&ouml;r"; break;
case "persone":  				$messaggio = "personer"; break;
case "Costo unico":  				$messaggio = "Enkel kostnad"; break;
case "moltiplicato per":  			$messaggio = "multiplicerad med"; break;
case "Costo settimanale":  			$messaggio = "Veckolig kostnad"; break;
case "Costo giornaliero":  			$messaggio = "Daglig kostnad"; break;
case "settimane":  				$messaggio = "veckor"; break;
case "giorni":  				$messaggio = "dagar"; break;
case "TOTALE":  				$messaggio = "TOTALT"; break;
case "Caparra":  				$messaggio = "Deposition"; break;
case "resto da pagare":  			$messaggio = "&aring;terst&aring;end att betala"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "inserita":  				$messaggio = "infogad"; break;
case "Modifica la prenotazione":  		$messaggio = "&Auml;ndra bokning"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Sconto":  				$messaggio = "Rabatt"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Kundens efternamn beh&ouml;vs"; break;
case "confermata":  				$messaggio = "bekr&auml;ftad"; break;
case "Confermata":  				$messaggio = "Bekr&auml;ftad"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Antalet bokningar av den h&auml;r typen"; break;
case "Aggiungi altre tipologie":  		$messaggio = "L&auml;gg till andra typer"; break;
case "Tipologia":  				$messaggio = "Typ"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Inga nya bokningar har lagts till"; break;
case "Transazione scaduta":  			$messaggio = "Transaktion utg&aring;ngen"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "Det var inte m&ouml;jligt att l&auml;gga till en extrakostnad f&ouml;r bokningen f&ouml;r"; break;
case "Orario stimato di entrata":  		$messaggio = "Uppskattad incheckningstid"; break;
case "giorno":  				$messaggio = "dag"; break;
case "Metodo pagamento caparra":  		$messaggio = "Betalningsmetod f&ouml;r depositionen"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "Bokningarna som efterfr&aring;gas i meddelandet har redan lagts till"; break;
case "Attenzione":  				$messaggio = "Varning"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "det totala priset f&ouml;r infogade bokningar"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "det totala priset f&ouml;r infogade depositioner"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "&auml;r skiljt fr&aring;n det som ing&aring;r i bokningsf&ouml;rfr&aring;gansmeddelandet"; break;
case "Origine":  				$messaggio = "Ursprung"; break;
case "<b>Attenzione</b>: il prezzo totale":  		$messaggio = "<b>Varning</b>: totalt pris"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "&auml;r skiljt fr&aring;n avl&auml;gset pris"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "&Auml;ndra infogade bokningar som en grupp"; break;
case "prezzo totale":  				$messaggio = "total price"; break;
case "prezzo totale giornaliero":  		$messaggio = "daily total price"; break;
case "prezzo totale settimanale":  		$messaggio = "weekly total price"; break;
case "prezzo tariffa":  			$messaggio = "rate price"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "daily rate price"; break;
case "prezzo tariffa settimanale":  		$messaggio = "weekly rate price"; break;
case "% del totale":  				$messaggio = "% of total"; break;
case "% della tariffa":  			$messaggio = "% of rate"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "resto commissioni":  			$messaggio = "rest of commissions"; break;
case "% del prezzo totale":  			$messaggio = "% of total price"; break;
case "modificata":  				$messaggio = "modified"; break;
case "Errore":  				$messaggio = "Error"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "per un promemoria all'entrata":  		$messaggio = "for a reminder at checkin"; break;
case "per un promemoria all'uscita":  		$messaggio = "for a reminder at checkout"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
